@@ -53,9 +53,9 @@ pub type TxBody = Vec<u8>;
 #[derive(Debug, Clone)]
 pub struct Tx(TxId, TxBody);
 
-impl Into<TxIdAndSize> for &Tx {
-    fn into(self) -> TxIdAndSize {
-        TxIdAndSize(self.0, self.1.len() as u32)
+impl From<&Tx> for TxIdAndSize {
+    fn from(other: &Tx) -> Self {
+        TxIdAndSize(other.0, other.1.len() as u32)
     }
 }
 
